#include <filesystem>

#include <Packet_Structure_Json.h>
#include <Astri_MA_Generic.h>
#include <AstriFitsProcessor.h>

namespace fs = std::filesystem;

void printLog(std::ostream &os, std::string message) {
	time_t now = time(nullptr);
	os << "[" << std::put_time(localtime(&now), "%Y-%m-%d %H:%M:%S")
			<< "]\t[Fits Processor]" << "\t" << message << std::endl;
}

int main(int argc, char **argv) {
	if (argc != 3) {
		std::cout << "Usage: " << argv[0] << " <source folder_path> <destination folder_path>\n";
		return 1;
	}


	const fs::path source(argv[1]);
	const fs::path destination(argv[2]);

	try {
		if (!fs::exists(source)) {
			printLog(std::cerr,
					"Invalid source directory path: " + source.string());
			return 1;
		}
		if (!fs::is_directory(source) && fs::is_regular_file(source)) { // single file
			const std::string filePath = source.string();
			AstriFitsProcessor fitsproc(filePath);
			fitsproc.setDestinationPath(destination);
			fitsproc.startProcessing();
		} else { // directory
			for (const auto &entry : fs::recursive_directory_iterator(source)) { // for each file in the directory
				if (!entry.is_regular_file()) {
					continue;
				}
				const std::string filePath = entry.path().string();
				AstriFitsProcessor fitsproc(filePath);
				fitsproc.setDestinationPath(destination);
				fitsproc.startProcessing();
			}
		}
	} catch (const std::exception &e) {
		printLog(std::cerr, "An error occurred: " + std::string(e.what()));
		return 1;
	}
	return 0;
}
